@@ -32,7 +32,7 @@ from logilab.astng import MANAGER, YES, InferenceContext, Instance, Generator, \
 from logilab.astng import ASTNGError, InferenceError, UnresolvableName, \
      NoDefault, NotFoundError, ASTNGBuildingException
 
-    
+
 def path_wrapper(func):
     """return the given infer function wrapped to handle the path"""
     def wrapped(node, context=None, _func=func, **kwargs):
@@ -57,6 +57,11 @@ def path_wrapper(func):
             raise
     return wrapped
 
+try:
+    GeneratorExit # py >= 2.5
+except:
+    class GeneratorExit(Exception): pass
+    
 # .infer method ###############################################################
 
 def infer_default(self, context=None):
@@ -131,7 +136,9 @@ class CallContext:
                             # XXX can do better ?
                             boundnode = funcnode.parent.frame()
                         if funcnode.type == 'method':
-                            return iter((Instance(boundnode),))
+                            if not isinstance(boundnode, Instance):
+                                boundnode = Instance(boundnode)
+                            return iter((boundnode,))
                         if funcnode.type == 'classmethod':
                             return iter((boundnode,))                            
                     # 2. search arg index
@@ -325,11 +332,12 @@ def _imported_module_astng(node, modname):
     # on relative imports
     # XXX: no more needed ?
     mymodule = node.root()
-    if mymodule.relative_name(modname) == mymodule.name:
+    level = getattr(node, 'level', None) # Import as no level
+    if mymodule.relative_name(modname, level) == mymodule.name:
         # FIXME: I don't know what to do here...
         raise InferenceError(modname)
     try:
-        return mymodule.import_module(modname)
+        return mymodule.import_module(modname, level=level)
     except (ASTNGBuildingException, SyntaxError):
         raise InferenceError(modname)
         
@@ -435,6 +443,8 @@ def _infer_operator(self, context=None, impl=None, meth='__method__'):
                 # will be the same
                 lhs.getattr(meth)
                 yield lhs
+            except GeneratorExit:
+                raise
             except:
                 yield YES
             continue
@@ -447,12 +457,14 @@ def _infer_operator(self, context=None, impl=None, meth='__method__'):
                     # will be the same
                     rhs.getattr(meth)
                     yield rhs
+                except GeneratorExit:
+                    raise
                 except:
                     yield YES
                 continue
             try:
                 value = impl(lhsvalue, rhsvalue)
-            except TypeError:
+            except: # TypeError:
                 yield YES
                 continue
             if type(value) is type(lhsvalue):
