@@ -84,6 +84,9 @@ from logilab.astng._exceptions import NotFoundError, InferenceError
 from logilab.astng.utils import extend_class
 from logilab.astng import InferenceContext
 
+# introduced in python 2.5
+From.level = 0 # will be overiden by instance attribute with py>=2.5
+
 import re
 ID_RGX = re.compile('^[a-zA-Z_][a-zA-Z_0-9]*$')
 del re
@@ -307,19 +310,28 @@ def try_except_block_range(node, lineno):
 
 TryExcept.block_range = try_except_block_range
 
+def try_finally_block_range(node, lineno, last=None):
+    """handle block line numbers range for try/finally"""
+    if lineno == node.source_line():
+        return lineno, lineno
+    if node.final:
+        if lineno > node.final.fromlineno:
+            return lineno, node.final.last_source_line()
+        return lineno, node.final.source_line() - 1
+    return lineno, last or node.last_source_line()
+
+TryFinally.block_range = try_finally_block_range
+
 def elsed_block_range(node, lineno, last=None):
-    """handle block line numbers range for try/finally, for and while
-    statements
-    """
+    """handle block line numbers range for if, for and while statements"""
     if lineno == node.source_line():
         return lineno, lineno
     if node.else_:
-        if lineno >= node.else_.source_line():
+        if lineno > node.else_.fromlineno:
             return lineno, node.else_.last_source_line()
         return lineno, node.else_.source_line() - 1
     return lineno, last or node.last_source_line()
 
-TryFinally.block_range = elsed_block_range
 While.block_range = elsed_block_range
 For.block_range = elsed_block_range
 
