@@ -14,6 +14,7 @@
 """
 
 import sys
+from StringIO import StringIO
 from logilab.common.testlib import TestCase, unittest_main
 
 from logilab.astng import builder, nodes, inference, YES, Instance, \
@@ -819,6 +820,63 @@ def f(x):
         infered = list(astng['f'].ilookup('a'))
         self.failUnlessEqual(len(infered), 1)
         self.failUnlessEqual(infered[0], YES)
+
+    def test_python25_generator_exit(self):
+        sys.stderr = StringIO()
+        data = "b = {}[str(0)+''].a"
+        astng = builder.string_build(data, __name__, __file__)
+        list(astng['b'].infer())
+        output = sys.stderr.getvalue()
+        # I have no idea how to test for this in another way...
+        self.failIf("RuntimeError" in output, "Exception exceptions.RuntimeError: 'generator ignored GeneratorExit' in <generator object> ignored")
+        sys.stderr = sys.__stderr__
         
+    def test_python25_relative_import(self):
+        data = "from ...common import date; print date"
+        astng = builder.string_build(data, 'logilab.astng.test.unittest_inference', __file__)
+        infered = get_name_node(astng, 'date').infer().next()
+        self.assertIsInstance(infered, nodes.Module)
+        self.assertEquals(infered.name, 'logilab.common.date')
+
+    def test_python25_no_relative_import(self):
+        data = 'import unittest_lookup; print unittest_lookup'
+        astng = builder.string_build(data, 'logilab.astng.test.unittest_inference', __file__)
+        self.failIf(astng.absolute_import_activated())
+#         infered = get_name_node(astng, 'unittest_lookup').infer().next()
+#         self.assertIsInstance(infered, nodes.Module)
+        # failed to import unittest_lookup since absolute_import is activated
+        data = 'from __future__ import absolute_import; import unittest_lookup; print unittest_lookup'
+        astng = builder.string_build(data, 'logilab.astng.test.unittest_inference', __file__)
+        self.failUnless(astng.absolute_import_activated(), True)
+#         infered = get_name_node(astng, 'unittest_lookup').infer().next()
+#         # failed to import unittest_lookup since absolute_import is activated
+#         self.failUnless(infered is YES)
+
+#     def test_mechanize_open(self):
+#         try:
+#             import mechanize
+#         except ImportError:
+#             self.skip('require mechanize installed')
+#         data = '''from mechanize import Browser
+# print Browser
+# b = Browser()
+# print b
+# '''
+#         astng = builder.string_build(data, __name__, __file__)
+#         browser = get_name_node(astng, 'Browser').infer().next()
+#         self.assertIsInstance(browser, nodes.Class)
+#         print '*'*80
+#         bopen = list(browser.igetattr('open'))
+#         self.assertEquals(len(bopen), 1)
+#         self.assertIsInstance(bopen[0], nodes.Function)
+#         self.failUnless(bopen[0].callable())
+#         print '*'*80
+#         b = get_name_node(astng, 'b').infer().next()
+#         self.assertIsInstance(b, Instance)
+#         bopen = list(b.igetattr('open'))
+#         self.assertEquals(len(bopen), 1)
+#         self.assertIsInstance(bopen[0], InstanceMethod)
+#         self.failUnless(bopen[0].callable())
+    
 if __name__ == '__main__':
     unittest_main()
