@@ -113,7 +113,40 @@ class A(A):
     def test_inner_classes(self):
         ccc = NONREGR['Ccc']
         self.assertEquals(ccc.ilookup('Ddd').next().name, 'Ddd')
-        
+
+    def test_loopvar_hiding(self):
+        astng = builder.string_build("""
+x = 10
+for x in range(5):
+    print x
+   
+if x > 0:
+    print '#' * x        
+        """, __name__, __file__)
+        xnames = [n for n in astng.nodes_of_class(nodes.Name) if n.name == 'x']
+        # inside the loop, only one possible assigment
+        self.assertEquals(len(xnames[0].lookup('x')[1]), 1)
+        # outside the loop, two possible assigments
+        self.assertEquals(len(xnames[1].lookup('x')[1]), 2)
+        self.assertEquals(len(xnames[2].lookup('x')[1]), 2)
+
+    def test_list_comps(self):
+        if sys.version_info < (2, 4):
+            self.skip('this test require python >= 2.4')
+        astng = builder.string_build("""
+print [ i for i in range(10) ]
+print [ i for i in range(10) ]
+print list( i for i in range(10) )
+        """, __name__, __file__)
+        xnames = [n for n in astng.nodes_of_class(nodes.Name) if n.name == 'i']
+        self.assertEquals(len(xnames[0].lookup('i')[1]), 1)
+        self.assertEquals(xnames[0].lookup('i')[1][0].lineno, 2)
+        self.assertEquals(len(xnames[1].lookup('i')[1]), 1)
+        self.assertEquals(xnames[1].lookup('i')[1][0].lineno, 3)
+        self.assertEquals(len(xnames[2].lookup('i')[1]), 1)
+        self.assertEquals(xnames[2].lookup('i')[1][0].lineno, 4)
+
+
     def test_nonregr_method_lookup(self):
         if sys.version_info < (2, 4):
             self.skip('this test require python >= 2.4')
@@ -135,7 +168,32 @@ class Test:
         obj = it.next()
         self.assertIsInstance(obj, nodes.Class)
         self.assertRaises(StopIteration, it.next)
-        
+
+    def test_decorator_arguments_lookup(self):
+        if sys.version_info < (2, 4):
+            self.skip('this test require python >= 2.4')
+        data = '''
+def decorator(value):
+   def wrapper(function):
+        return function
+   return wrapper
+
+class foo:
+  member = 10
+
+  @decorator(member) #This will cause pylint to complain
+  def test(self):
+       pass
+        ''' 
+        astng = builder.string_build(data, __name__, __file__)
+        member = get_name_node(astng['foo'], 'member')
+        print 'oop', member.lineno
+        it = member.infer()
+        obj = it.next()
+        self.assertIsInstance(obj, nodes.Const)
+        self.assertEquals(obj.value, 10)
+        self.assertRaises(StopIteration, it.next)
+       
     def test_nonregr_decorator_member_lookup(self):
         if sys.version_info < (2, 4):
             self.skip('this test require python >= 2.4')
